@@ -1,9 +1,11 @@
 require 'spec_helper_acceptance'
 
-describe 'puppet resource firewallchain command:', :unless => UNSUPPORTED_PLATFORMS.include?(fact('osfamily')) do
+describe 'puppet resource firewallchain command' do
   before :all do
     iptables_flush_all_tables
+    ip6tables_flush_all_tables
   end
+
   describe 'ensure' do
     context 'present' do
       it 'applies cleanly' do
