@@ -1,8 +1,9 @@
 require 'spec_helper_acceptance'
 
-if default['platform'] =~ /el-5/
-  describe "firewall ip6tables doesn't work on 1.3.5 because --comment is missing", :unless => UNSUPPORTED_PLATFORMS.include?(fact('osfamily')) do
+if default['platform'] =~ /el-5/ or default['platform'] =~ /sles-10/
+  describe "firewall ip6tables doesn't work on 1.3.5 because --comment is missing" do
     before :all do
+      iptables_flush_all_tables
       ip6tables_flush_all_tables
     end
 
@@ -19,8 +20,9 @@ if default['platform'] =~ /el-5/
     end
   end
 else
-  describe 'firewall ishasmorefrags/islastfrag/isfirstfrag properties', :unless => UNSUPPORTED_PLATFORMS.include?(fact('osfamily')) do
+  describe 'firewall ishasmorefrags/islastfrag/isfirstfrag properties' do
     before :all do
+      iptables_flush_all_tables
       ip6tables_flush_all_tables
     end
 
@@ -37,7 +39,7 @@ else
         EOS
 
         apply_manifest(pp, :catch_failures => true)
-        apply_manifest(pp, :catch_changes => true)
+        apply_manifest(pp, :catch_changes => do_catch_changes)
 
         shell('ip6tables-save') do |r|
           expect(r.stdout).to match(/#{line_match}/)
@@ -56,7 +58,7 @@ else
             }
         EOS
 
-        apply_manifest(pp, :catch_changes => true)
+        apply_manifest(pp, :catch_changes => do_catch_changes)
 
         shell('ip6tables-save') do |r|
           expect(r.stdout).to match(/#{line_match}/)
