@@ -1,8 +1,9 @@
 require 'spec_helper_acceptance'
 
-describe 'complex ruleset 1', :unless => UNSUPPORTED_PLATFORMS.include?(fact('osfamily')) do
+describe 'complex ruleset 1' do
   before :all do
     iptables_flush_all_tables
+    ip6tables_flush_all_tables
   end
 
   after :all do
@@ -127,7 +128,7 @@ describe 'complex ruleset 2' do
   it 'applies cleanly' do
     pp = <<-EOS
       class { '::firewall': }
-      
+
       Firewall {
         proto => 'all',
         stage => 'pre',
@@ -140,12 +141,26 @@ describe 'complex ruleset 2' do
         ],
       }
 
+      firewall { '001 ssh needed for beaker testing':
+        proto   => 'tcp',
+        dport   => '22',
+        action  => 'accept',
+        before => Firewallchain['INPUT:filter:IPv4'],
+      }
+
       firewall { '010 INPUT allow established and related':
         proto  => 'all',
         state  => ['ESTABLISHED', 'RELATED'],
         action => 'accept',
         before => Firewallchain['INPUT:filter:IPv4'],
       }
+
+      firewall { "011 reject local traffic not on loopback interface":
+        iniface     => '! lo',
+        proto       => 'all',
+        destination => '127.0.0.1/8',
+        action      => 'reject',
+      }
       firewall { '012 accept loopback':
         iniface => 'lo',
         action  => 'accept',
@@ -159,6 +174,14 @@ describe 'complex ruleset 2' do
         before => Firewallchain['INPUT:filter:IPv4'],
       }
 
+      firewall { '025 smtp':
+        outiface => '! eth0:2',
+        chain    => 'OUTPUT',
+        proto    => 'tcp',
+        dport    => '25',
+        state    => 'NEW',
+        action   => 'accept',
+      }
       firewall { '013 icmp echo-request':
         proto  => 'icmp',
         icmp   => 'echo-request',
@@ -175,12 +198,14 @@ describe 'complex ruleset 2' do
         icmp   => 'time-exceeded',
         action => 'accept',
       }
-      firewall { '999 reject':
-        action => 'reject',
-        reject => 'icmp-host-prohibited',
+      firewall { '443 ssl on aliased interface':
+        proto   => 'tcp',
+        dport   => '443',
+        state   => 'NEW',
+        action  => 'accept',
+        iniface => 'eth0:3',
       }
 
-
       firewallchain { 'LOCAL_INPUT_PRE:filter:IPv4': }
       firewall { '001 LOCAL_INPUT_PRE':
         jump    => 'LOCAL_INPUT_PRE',
@@ -223,7 +248,7 @@ describe 'complex ruleset 2' do
 
     # Run it twice and test for idempotency
     apply_manifest(pp, :catch_failures => true)
-    apply_manifest(pp, :catch_changes => true)
+    apply_manifest(pp, :catch_changes => do_catch_changes)
   end
 
   it 'contains appropriate rules' do
@@ -236,13 +261,16 @@ describe 'complex ruleset 2' do
         /LOCAL_INPUT_PRE/,
         /-A INPUT -m comment --comment \"001 LOCAL_INPUT_PRE\" -j LOCAL_INPUT_PRE/,
         /-A INPUT -m comment --comment \"010 INPUT allow established and related\" -m state --state RELATED,ESTABLISHED -j ACCEPT/,
+        /-A INPUT -d 127.0.0.0\/(8|255\.0\.0\.0) (! -i|-i !) lo -m comment --comment \"011 reject local traffic not on loopback interface\" -j REJECT --reject-with icmp-port-unreachable/,
         /-A INPUT -i lo -m comment --comment \"012 accept loopback\" -j ACCEPT/,
         /-A INPUT -p icmp -m comment --comment \"013 icmp destination-unreachable\" -m icmp --icmp-type 3 -j ACCEPT/,
         /-A INPUT -s 10.0.0.0\/(8|255\.0\.0\.0) -p icmp -m comment --comment \"013 icmp echo-request\" -m icmp --icmp-type 8 -j ACCEPT/,
         /-A INPUT -p icmp -m comment --comment \"013 icmp time-exceeded\" -m icmp --icmp-type 11 -j ACCEPT/,
         /-A INPUT -p tcp -m multiport --dports 22 -m comment --comment \"020 ssh\" -m state --state NEW -j ACCEPT/,
+        /-A INPUT -p tcp -m multiport --dports 22 -m comment --comment \"001 ssh needed for beaker testing\" -j ACCEPT/,
+        /-A OUTPUT (! -o|-o !) eth0:2 -p tcp -m multiport --dports 25 -m comment --comment \"025 smtp\" -m state --state NEW -j ACCEPT/,
+        /-A INPUT -i eth0:3 -p tcp -m multiport --dports 443 -m comment --comment \"443 ssl on aliased interface\" -m state --state NEW -j ACCEPT/,
         /-A INPUT -m comment --comment \"900 LOCAL_INPUT\" -j LOCAL_INPUT/,
-        /-A INPUT -m comment --comment \"999 reject\" -j REJECT --reject-with icmp-host-prohibited/,
         /-A FORWARD -m comment --comment \"010 allow established and related\" -m state --state RELATED,ESTABLISHED -j ACCEPT/
       ].each do |line|
         expect(r.stdout).to match(line)
