@@ -8,7 +8,7 @@ def iptables_flush_all_tables
 end
 
 def ip6tables_flush_all_tables
-  ['filter'].each do |t|
+  ['filter', 'mangle'].each do |t|
     expect(shell("ip6tables -t #{t} -F").stderr).to eq("")
   end
 end
@@ -23,21 +23,19 @@ end
 
 run_puppet_install_helper
 
-UNSUPPORTED_PLATFORMS = ['windows','Solaris','Darwin']
-
 RSpec.configure do |c|
   # Project root
   proj_root = File.expand_path(File.join(File.dirname(__FILE__), '..'))
 
-  # Readable test descriptions
-  c.formatter = :documentation
-
   # Configure all nodes in nodeset
   c.before :suite do
     # Install module and dependencies
     hosts.each do |host|
       copy_module_to(host, :source => proj_root, :module_name => 'firewall')
-      on host, puppet('module install puppetlabs-stdlib --version 3.2.0'), { :acceptable_exit_codes => [0,1] }
+      on host, puppet('module install puppetlabs-stdlib --version 3.2.0')
+
+      # the ubuntu-14.04 docker image doesn't carry the iptables command
+      apply_manifest_on host, 'package { "iptables": ensure => installed }' if fact('osfamily') == 'Debian'
     end
   end
 end
